@@ -5,7 +5,7 @@ from pypulseprofiles.core import pulse_apply
 
 def main(args=None):
     """
-    Outputs information about the PulseAudio setup.
+    Applies a PulseAudio profile in YAML format.
     Use -h to see all options.
 
     :param args: the command-line arguments to use, uses sys.argv if None
@@ -13,8 +13,9 @@ def main(args=None):
     """
 
     parser = argparse.ArgumentParser(
-        description='Applies a PulseAudio profile in YAML format.', prog="ppp-apply")
-    parser.add_argument("--config", metavar="NAME_OR_FILE", dest="config", default=None, help="the file (or config name) to load the profile from, outputs it to stdout if not provided")
+        description='Applies a PulseAudio profile in YAML format.',
+        prog="ppp-apply")
+    parser.add_argument("--config", metavar="NAME_OR_FILE", dest="config", required=True, help="the file (or config name) to load the profile from, outputs it to stdout if not provided")
     parser.add_argument("--volume", action="store_true", dest="volume", help="whether to set the (average) volume across all channels")
     parsed = parser.parse_args(args=args)
     pulse_apply(config=parsed.config, volume=parsed.volume)
